# This file was auto-generated by Fern from our API Definition.

from ....core.pydantic_utilities import UniversalBaseModel
import pydantic
from ....core.pydantic_utilities import IS_PYDANTIC_V2
import typing


class SentimentScore(UniversalBaseModel):
    name: str = pydantic.Field()
    """
    Level of sentiment, ranging from `1` (negative) to `9` (positive)
    """

    score: float = pydantic.Field()
    """
    Prediction for this level of sentiment
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
